==> igniteui-react-18.2.2-beta.0.tgz: package/esm5/lib/SliderBase.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { SliderBaseTickOrientation_$type } from "./SliderBaseTickOrientation";
import { TickLabelRotation_$type } from "./TickLabelRotation";
/**
 * @hidden
 */
var SliderBase = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SliderBase, _super);
    function SliderBase() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.d = new WCNativeHelper();
        _this.r = null;
        return _this;
    }
    Object.defineProperty(SliderBase.prototype, "e", {
        get: function () {
            return this.d;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SliderBase.prototype, "nativeElement", {
        get: function () {
            return this.r;
        },
        set: function (a) {
            this.r = a;
            this.d.n = this.r;
        },
        enumerable: false,
        configurable: true
    });
    SliderBase.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(SliderBase.prototype, "m", {
        get: function () {
            var ret_ = this.e.m("min");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("min", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SliderBase.prototype, "l", {
        get: function () {
            var ret_ = this.e.m("max");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("max", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SliderBase.prototype, "k", {
        get: function () {
            var ret_ = this.e.m("lowerBound");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("lowerBound", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SliderBase.prototype, "q", {
        get: function () {
            var ret_ = this.e.m("upperBound");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("upperBound", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SliderBase.prototype, "f", {
        get: function () {
            var ret_ = this.e.m("disabled");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("disabled", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SliderBase.prototype, "g", {
        get: function () {
            var ret_ = this.e.m("discreteTrack");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("discreteTrack", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SliderBase.prototype, "j", {
        get: function () {
            var ret_ = this.e.m("hideTooltip");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("hideTooltip", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SliderBase.prototype, "p", {
        get: function () {
            var ret_ = this.e.m("step");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("step", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SliderBase.prototype, "n", {
        get: function () {
            var ret_ = this.e.m("primaryTicks");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("primaryTicks", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SliderBase.prototype, "o", {
        get: function () {
            var ret_ = this.e.m("secondaryTicks");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("secondaryTicks", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SliderBase.prototype, "b", {
        get: function () {
            var ret_ = this.e.m("tickOrientation");
            ret_ = enumGetBox(SliderBaseTickOrientation_$type, EnumUtil.getEnumValue(SliderBaseTickOrientation_$type, this.e.f(SliderBaseTickOrientation_$type, ret_)));
            return EnumUtil.getEnumValue(SliderBaseTickOrientation_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(SliderBaseTickOrientation_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.e.u("tickOrientation", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SliderBase.prototype, "h", {
        get: function () {
            var ret_ = this.e.m("hidePrimaryLabels");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("hidePrimaryLabels", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SliderBase.prototype, "i", {
        get: function () {
            var ret_ = this.e.m("hideSecondaryLabels");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("hideSecondaryLabels", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SliderBase.prototype, "t", {
        get: function () {
            var ret_ = this.e.m("locale");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("locale", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SliderBase.prototype, "u", {
        get: function () {
            var ret_ = this.e.m("valueFormat");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("valueFormat", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SliderBase.prototype, "c", {
        get: function () {
            var ret_ = this.e.m("tickLabelRotation");
            ret_ = enumGetBox(TickLabelRotation_$type, EnumUtil.getEnumValue(TickLabelRotation_$type, this.e.f(TickLabelRotation_$type, ret_)));
            return EnumUtil.getEnumValue(TickLabelRotation_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(TickLabelRotation_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.e.u("tickLabelRotation", value_);
        },
        enumerable: false,
        configurable: true
    });
    SliderBase.prototype.v = function () {
        this.nativeElement.connectedCallback();
    };
    SliderBase.prototype.w = function () {
        this.nativeElement.disconnectedCallback();
    };
    Object.defineProperty(SliderBase.prototype, "a", {
        get: function () {
            var ret_ = this.e.m("valueFormatOptions");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("valueFormatOptions", value_);
        },
        enumerable: false,
        configurable: true
    });
    SliderBase.$t = markType(SliderBase, 'SliderBase', BaseElement.$);
    return SliderBase;
}(BaseElement));
export { SliderBase };

==> igniteui-react-18.3.0-beta.0.tgz: package/esm5/lib/SliderBase.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { SliderBaseTickOrientation_$type } from "./SliderBaseTickOrientation";
import { TickLabelRotation_$type } from "./TickLabelRotation";
/**
 * @hidden
 */
var SliderBase = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SliderBase, _super);
    function SliderBase() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.d = new WCNativeHelper();
        _this.r = null;
        return _this;
    }
    Object.defineProperty(SliderBase.prototype, "e", {
        get: function () {
            return this.d;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SliderBase.prototype, "nativeElement", {
        get: function () {
            return this.r;
        },
        set: function (a) {
            this.r = a;
            this.d.o = this.r;
        },
        enumerable: false,
        configurable: true
    });
    SliderBase.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(SliderBase.prototype, "m", {
        get: function () {
            var ret_ = this.e.n("min");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.v("min", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SliderBase.prototype, "l", {
        get: function () {
            var ret_ = this.e.n("max");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.v("max", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SliderBase.prototype, "k", {
        get: function () {
            var ret_ = this.e.n("lowerBound");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.v("lowerBound", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SliderBase.prototype, "q", {
        get: function () {
            var ret_ = this.e.n("upperBound");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.v("upperBound", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SliderBase.prototype, "f", {
        get: function () {
            var ret_ = this.e.n("disabled");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.v("disabled", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SliderBase.prototype, "g", {
        get: function () {
            var ret_ = this.e.n("discreteTrack");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.v("discreteTrack", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SliderBase.prototype, "j", {
        get: function () {
            var ret_ = this.e.n("hideTooltip");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.v("hideTooltip", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SliderBase.prototype, "p", {
        get: function () {
            var ret_ = this.e.n("step");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.v("step", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SliderBase.prototype, "n", {
        get: function () {
            var ret_ = this.e.n("primaryTicks");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.v("primaryTicks", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SliderBase.prototype, "o", {
        get: function () {
            var ret_ = this.e.n("secondaryTicks");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.v("secondaryTicks", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SliderBase.prototype, "b", {
        get: function () {
            var ret_ = this.e.n("tickOrientation");
            ret_ = enumGetBox(SliderBaseTickOrientation_$type, EnumUtil.getEnumValue(SliderBaseTickOrientation_$type, this.e.f(SliderBaseTickOrientation_$type, ret_)));
            return EnumUtil.getEnumValue(SliderBaseTickOrientation_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(SliderBaseTickOrientation_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.e.v("tickOrientation", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SliderBase.prototype, "h", {
        get: function () {
            var ret_ = this.e.n("hidePrimaryLabels");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.v("hidePrimaryLabels", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SliderBase.prototype, "i", {
        get: function () {
            var ret_ = this.e.n("hideSecondaryLabels");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.v("hideSecondaryLabels", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SliderBase.prototype, "t", {
        get: function () {
            var ret_ = this.e.n("locale");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.v("locale", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SliderBase.prototype, "u", {
        get: function () {
            var ret_ = this.e.n("valueFormat");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.v("valueFormat", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SliderBase.prototype, "c", {
        get: function () {
            var ret_ = this.e.n("tickLabelRotation");
            ret_ = enumGetBox(TickLabelRotation_$type, EnumUtil.getEnumValue(TickLabelRotation_$type, this.e.f(TickLabelRotation_$type, ret_)));
            return EnumUtil.getEnumValue(TickLabelRotation_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(TickLabelRotation_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.e.v("tickLabelRotation", value_);
        },
        enumerable: false,
        configurable: true
    });
    SliderBase.prototype.v = function () {
        this.nativeElement.connectedCallback();
    };
    SliderBase.prototype.w = function () {
        this.nativeElement.disconnectedCallback();
    };
    Object.defineProperty(SliderBase.prototype, "a", {
        get: function () {
            var ret_ = this.e.n("valueFormatOptions");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.v("valueFormatOptions", value_);
        },
        enumerable: false,
        configurable: true
    });
    SliderBase.$t = markType(SliderBase, 'SliderBase', BaseElement.$);
    return SliderBase;
}(BaseElement));
export { SliderBase };
